You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@flex.apache.org by ah...@apache.org on 2015/04/24 08:16:46 UTC

[6/9] git commit: [flex-asjs] [refs/heads/develop] - fix up files after renaming mx classes

fix up files after renaming mx classes


Project: http://git-wip-us.apache.org/repos/asf/flex-asjs/repo
Commit: http://git-wip-us.apache.org/repos/asf/flex-asjs/commit/d54a5937
Tree: http://git-wip-us.apache.org/repos/asf/flex-asjs/tree/d54a5937
Diff: http://git-wip-us.apache.org/repos/asf/flex-asjs/diff/d54a5937

Branch: refs/heads/develop
Commit: d54a593714be1468114f1b9dfb6083380f0a41b4
Parents: 6dc5cfb
Author: Alex Harui <ah...@apache.org>
Authored: Thu Apr 23 11:42:02 2015 -0700
Committer: Alex Harui <ah...@apache.org>
Committed: Thu Apr 23 11:42:02 2015 -0700

----------------------------------------------------------------------
 examples/DataBindingTest/src/MyInitialView.mxml |  4 +--
 examples/FlexJSStore/src/FlexJSStore.mxml       | 20 +++++++-------
 examples/FlexJSStore/src/ProductsView.mxml      |  4 +--
 .../src/productsView/CatalogTitleButtons.mxml   |  4 +--
 .../src/productsView/ProductCatalogPanel.mxml   |  6 ++---
 .../productsView/ProductCatalogThumbnail.mxml   |  8 +++---
 .../src/productsView/ProductDetails.mxml        |  4 +--
 .../src/productsView/ProductFilterPanel.mxml    |  4 +--
 .../src/productsView/ProductListItem.mxml       |  4 +--
 frameworks/air-config-template.xml              | 12 +++++++++
 frameworks/air-config.xml                       | 12 +++++++++
 frameworks/flex-config-template.xml             | 10 +++++--
 frameworks/flex-config.xml                      | 10 +++++--
 .../org/apache/flex/charts/core/IChartSeries.as |  2 +-
 .../flex/charts/supportClasses/BarSeries.as     |  2 +-
 .../flex/charts/supportClasses/ColumnSeries.as  |  2 +-
 .../flex/charts/supportClasses/LineSeries.as    |  2 +-
 .../flex/charts/supportClasses/PieSeries.as     |  2 +-
 .../apache/flex/charts/core/IChartDataGroup.js  |  2 +-
 .../org/apache/flex/charts/core/IChartSeries.js |  2 +-
 frameworks/projects/Core/as/src/CoreClasses.as  | 10 +++----
 .../as/src/org/apache/flex/core/ClassFactory.as |  6 ++---
 .../src/org/apache/flex/core/ContainerBase.as   |  4 +--
 .../as/src/org/apache/flex/core/IFactory.as     |  2 +-
 .../flex/core/IItemRendererClassFactory.as      |  2 +-
 .../src/org/apache/flex/core/IStatesObject.as   |  2 +-
 .../flex/core/ItemRendererClassFactory.as       |  4 +--
 .../org/apache/flex/core/SimpleStatesImpl.as    |  8 +++---
 .../as/src/org/apache/flex/states/AddItems.as   |  2 +-
 .../org/apache/flex/states/ItemAndDescriptor.as |  2 +-
 .../org/apache/flex/states/SetEventHandler.as   |  2 +-
 .../src/org/apache/flex/states/SetProperty.as   |  2 +-
 .../Core/as/src/org/apache/flex/states/State.as |  2 +-
 frameworks/projects/Core/basic-manifest.xml     |  4 ++-
 frameworks/projects/Core/compile-config.xml     |  5 ----
 .../js/src/org/apache/flex/core/ClassFactory.js | 16 +++++------
 .../js/src/org/apache/flex/core/IFactory.js     | 10 +++----
 .../flex/core/ItemRendererClassFactory.js       |  4 +--
 .../org/apache/flex/core/SimpleStatesImpl.js    | 24 ++++++++---------
 .../js/src/org/apache/flex/states/AddItems.js   | 28 ++++++++++----------
 .../org/apache/flex/states/SetEventHandler.js   | 20 +++++++-------
 .../src/org/apache/flex/states/SetProperty.js   | 22 +++++++--------
 .../Core/js/src/org/apache/flex/states/State.js | 12 ++++-----
 frameworks/projects/Core/mx-manifest.xml        | 26 ------------------
 .../flex/core/StatesWithTransitionsImpl.as      |  8 +++---
 .../asjs/src/org/apache/flex/effects/Tween.as   |  6 ++---
 .../HTML/as/src/org/apache/flex/html/List.as    |  2 +-
 .../org/apache/flex/html/MXMLBeadViewBase.as    |  4 +--
 .../flex/html/supportClasses/DataGridColumn.as  |  2 +-
 .../HTML/js/src/org/apache/flex/html/List.js    |  2 +-
 .../flex/html/supportClasses/DataGridColumn.js  |  2 +-
 51 files changed, 184 insertions(+), 177 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/examples/DataBindingTest/src/MyInitialView.mxml
----------------------------------------------------------------------
diff --git a/examples/DataBindingTest/src/MyInitialView.mxml b/examples/DataBindingTest/src/MyInitialView.mxml
index f81deeb..3dcaa1e 100644
--- a/examples/DataBindingTest/src/MyInitialView.mxml
+++ b/examples/DataBindingTest/src/MyInitialView.mxml
@@ -97,8 +97,8 @@ limitations under the License.
         }
 	</fx:Style>
     <js:states>
-        <mx:State name="hideAll" />        
-        <mx:State name="showAll" />        
+        <js:State name="hideAll" />        
+        <js:State name="showAll" />        
     </js:states>
     <js:beads>
         <js:ViewBaseDataBinding />

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/examples/FlexJSStore/src/FlexJSStore.mxml
----------------------------------------------------------------------
diff --git a/examples/FlexJSStore/src/FlexJSStore.mxml b/examples/FlexJSStore/src/FlexJSStore.mxml
index a3a1d10..5824acc 100755
--- a/examples/FlexJSStore/src/FlexJSStore.mxml
+++ b/examples/FlexJSStore/src/FlexJSStore.mxml
@@ -191,16 +191,16 @@ limitations under the License.
                         initComplete="completeHandler(null)"
                         stateChangeComplete="chainStatesIfNeeded()">
             <js:states>
-                <mx:State name="HomeState" stateGroups="['Home']" />
-                <mx:State name="HomeWipeUp" stateGroups="['Home']" />
-                <mx:State name="HomeWipeDown" stateGroups="['Home']" />
-                <mx:State name="ProductsPreBake" stateGroups="['Home', 'Products']" />
-                <mx:State name="ProductsState" stateGroups="['Products']" />
-                <mx:State name="ProductsWipeUp" stateGroups="['Products']" />
-                <mx:State name="ProductsWipeDown" stateGroups="['Products']" />
-                <mx:State name="SupportState" stateGroups="['Support']" />
-                <mx:State name="SupportWipeUp" stateGroups="['Support']" />
-                <mx:State name="SupportWipeDown" stateGroups="['Support']" />
+                <js:State name="HomeState" stateGroups="['Home']" />
+                <js:State name="HomeWipeUp" stateGroups="['Home']" />
+                <js:State name="HomeWipeDown" stateGroups="['Home']" />
+                <js:State name="ProductsPreBake" stateGroups="['Home', 'Products']" />
+                <js:State name="ProductsState" stateGroups="['Products']" />
+                <js:State name="ProductsWipeUp" stateGroups="['Products']" />
+                <js:State name="ProductsWipeDown" stateGroups="['Products']" />
+                <js:State name="SupportState" stateGroups="['Support']" />
+                <js:State name="SupportWipeUp" stateGroups="['Support']" />
+                <js:State name="SupportWipeDown" stateGroups="['Support']" />
             </js:states>
             
             <js:transitions>

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/examples/FlexJSStore/src/ProductsView.mxml
----------------------------------------------------------------------
diff --git a/examples/FlexJSStore/src/ProductsView.mxml b/examples/FlexJSStore/src/ProductsView.mxml
index 54e1603..b28c9fe 100755
--- a/examples/FlexJSStore/src/ProductsView.mxml
+++ b/examples/FlexJSStore/src/ProductsView.mxml
@@ -109,8 +109,8 @@ limitations under the License.
     </productsView:ProductCatalogPanel>
     
     <js:states>
-       <mx:State name="showFilter" />
-       <mx:State name="showCart" />
+       <js:State name="showFilter" />
+       <js:State name="showCart" />
     </js:states>
     
     <!-- 

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/examples/FlexJSStore/src/productsView/CatalogTitleButtons.mxml
----------------------------------------------------------------------
diff --git a/examples/FlexJSStore/src/productsView/CatalogTitleButtons.mxml b/examples/FlexJSStore/src/productsView/CatalogTitleButtons.mxml
index 1d2ae72..1df074a 100755
--- a/examples/FlexJSStore/src/productsView/CatalogTitleButtons.mxml
+++ b/examples/FlexJSStore/src/productsView/CatalogTitleButtons.mxml
@@ -64,7 +64,7 @@ limitations under the License.
              rollOut.showFilter="rollOutLabel(event)"/>
     
     <js:states>
-        <mx:State name="showFilter" />
-        <mx:State name="showCart" />
+        <js:State name="showFilter" />
+        <js:State name="showCart" />
     </js:states>
 </js:HContainer>

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/examples/FlexJSStore/src/productsView/ProductCatalogPanel.mxml
----------------------------------------------------------------------
diff --git a/examples/FlexJSStore/src/productsView/ProductCatalogPanel.mxml b/examples/FlexJSStore/src/productsView/ProductCatalogPanel.mxml
index e079ad2..04e9a9f 100755
--- a/examples/FlexJSStore/src/productsView/ProductCatalogPanel.mxml
+++ b/examples/FlexJSStore/src/productsView/ProductCatalogPanel.mxml
@@ -540,9 +540,9 @@ limitations under the License.
     </js:Container>
     
     <js:states>
-        <mx:State name="browse" />
-        <mx:State name="compare" />
-        <mx:State name="details" />
+        <js:State name="browse" />
+        <js:State name="compare" />
+        <js:State name="details" />
     </js:states>
     
 </js:Panel>

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/examples/FlexJSStore/src/productsView/ProductCatalogThumbnail.mxml
----------------------------------------------------------------------
diff --git a/examples/FlexJSStore/src/productsView/ProductCatalogThumbnail.mxml b/examples/FlexJSStore/src/productsView/ProductCatalogThumbnail.mxml
index df70ab5..2105a88 100755
--- a/examples/FlexJSStore/src/productsView/ProductCatalogThumbnail.mxml
+++ b/examples/FlexJSStore/src/productsView/ProductCatalogThumbnail.mxml
@@ -209,13 +209,13 @@ limitations under the License.
 
     <js:states>
 
-        <mx:State name="compare" />
+        <js:State name="compare" />
 
-        <mx:State name="x4cols" />
+        <js:State name="x4cols" />
 
-        <mx:State name="x3cols" />
+        <js:State name="x3cols" />
 
-        <mx:State name="x2cols"/>
+        <js:State name="x2cols"/>
     </js:states>
 
 </js:Container>

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/examples/FlexJSStore/src/productsView/ProductDetails.mxml
----------------------------------------------------------------------
diff --git a/examples/FlexJSStore/src/productsView/ProductDetails.mxml b/examples/FlexJSStore/src/productsView/ProductDetails.mxml
index 4e22f74..4fdca19 100755
--- a/examples/FlexJSStore/src/productsView/ProductDetails.mxml
+++ b/examples/FlexJSStore/src/productsView/ProductDetails.mxml
@@ -60,8 +60,8 @@ limitations under the License.
     </fx:Declarations>
 
     <js:states>
-        <mx:State name="Features" />
-        <mx:State name="Support" />
+        <js:State name="Features" />
+        <js:State name="Support" />
     </js:states>
     
     <js:transitions>

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/examples/FlexJSStore/src/productsView/ProductFilterPanel.mxml
----------------------------------------------------------------------
diff --git a/examples/FlexJSStore/src/productsView/ProductFilterPanel.mxml b/examples/FlexJSStore/src/productsView/ProductFilterPanel.mxml
index 5240c0e..6f038e9 100755
--- a/examples/FlexJSStore/src/productsView/ProductFilterPanel.mxml
+++ b/examples/FlexJSStore/src/productsView/ProductFilterPanel.mxml
@@ -209,8 +209,8 @@ limitations under the License.
                   image.showingComparison="assets/icon_tiles.png" />
     
     <js:states>
-       <mx:State name="showingThumbnails" />
-       <mx:State name="showingComparison" />
+       <js:State name="showingThumbnails" />
+       <js:State name="showingComparison" />
     </js:states>
 
 </js:VContainer>

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/examples/FlexJSStore/src/productsView/ProductListItem.mxml
----------------------------------------------------------------------
diff --git a/examples/FlexJSStore/src/productsView/ProductListItem.mxml b/examples/FlexJSStore/src/productsView/ProductListItem.mxml
index bf6a2a8..f533609 100755
--- a/examples/FlexJSStore/src/productsView/ProductListItem.mxml
+++ b/examples/FlexJSStore/src/productsView/ProductListItem.mxml
@@ -124,8 +124,8 @@ limitations under the License.
     </js:TextInput>
     
     <js:states>
-        <mx:State name="compare" />
-        <mx:State name="showQuantity" />
+        <js:State name="compare" />
+        <js:State name="showQuantity" />
     </js:states>
     
 </js:Container>

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/air-config-template.xml
----------------------------------------------------------------------
diff --git a/frameworks/air-config-template.xml b/frameworks/air-config-template.xml
index 20ed8ec..e6c68d2 100644
--- a/frameworks/air-config-template.xml
+++ b/frameworks/air-config-template.xml
@@ -83,10 +83,22 @@
      
      <mxml>
          <children-as-data>true</children-as-data>
+         <imports>
+             <implicit-import>org.apache.flex.events.*</implicit-import>
+             <implicit-import>org.apache.flex.geom.*</implicit-import>
+             <implicit-import>org.apache.flex.core.ClassFactory</implicit-import>
+             <implicit-import>org.apache.flex.core.IFactory</implicit-import>
+         </imports>
      </mxml>
      <binding-value-change-event>org.apache.flex.events.ValueChangeEvent</binding-value-change-event>
      <binding-value-change-event-kind>org.apache.flex.events.ValueChangeEvent</binding-value-change-event-kind>
      <binding-value-change-event-type>valueChange</binding-value-change-event-type>
+     <states-class>org.apache.flex.states.State</states-class>
+     <states-instance-override-class>org.apache.flex.states.AddItems</states-instance-override-class>
+     <states-property-override-class>org.apache.flex.states.SetProperty</states-property-override-class>
+     <states-event-override-class>org.apache.flex.states.SetEventHandler</states-event-override-class>
+     <component-factory-class>org.apache.flex.core.ClassFactory</component-factory-class>
+     <component-factory-interface>org.apache.flex.core.IFactory</component-factory-interface>
 
      <namespaces>
       <!-- Specify a URI to associate with a manifest of components for use as MXML -->

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/air-config.xml
----------------------------------------------------------------------
diff --git a/frameworks/air-config.xml b/frameworks/air-config.xml
index 789c730..8f82882 100644
--- a/frameworks/air-config.xml
+++ b/frameworks/air-config.xml
@@ -83,10 +83,22 @@
      
      <mxml>
          <children-as-data>true</children-as-data>
+         <imports>
+             <implicit-import>org.apache.flex.events.*</implicit-import>
+             <implicit-import>org.apache.flex.geom.*</implicit-import>
+             <implicit-import>org.apache.flex.core.ClassFactory</implicit-import>
+             <implicit-import>org.apache.flex.core.IFactory</implicit-import>
+         </imports>
      </mxml>
      <binding-value-change-event>org.apache.flex.events.ValueChangeEvent</binding-value-change-event>
      <binding-value-change-event-kind>org.apache.flex.events.ValueChangeEvent</binding-value-change-event-kind>
      <binding-value-change-event-type>valueChange</binding-value-change-event-type>
+     <states-class>org.apache.flex.states.State</states-class>
+     <states-instance-override-class>org.apache.flex.states.AddItems</states-instance-override-class>
+     <states-property-override-class>org.apache.flex.states.SetProperty</states-property-override-class>
+     <states-event-override-class>org.apache.flex.states.SetEventHandler</states-event-override-class>
+     <component-factory-class>org.apache.flex.core.ClassFactory</component-factory-class>
+     <component-factory-interface>org.apache.flex.core.IFactory</component-factory-interface>
 
      <namespaces>
       <!-- Specify a URI to associate with a manifest of components for use as MXML -->

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/flex-config-template.xml
----------------------------------------------------------------------
diff --git a/frameworks/flex-config-template.xml b/frameworks/flex-config-template.xml
index c003483..4aaaed5 100644
--- a/frameworks/flex-config-template.xml
+++ b/frameworks/flex-config-template.xml
@@ -87,8 +87,8 @@
           <imports>
               <implicit-import>org.apache.flex.events.*</implicit-import>
               <implicit-import>org.apache.flex.geom.*</implicit-import>
-              <implicit-import>mx.core.ClassFactory</implicit-import>
-              <implicit-import>mx.core.IFactory</implicit-import>
+              <implicit-import>org.apache.flex.core.ClassFactory</implicit-import>
+              <implicit-import>org.apache.flex.core.IFactory</implicit-import>
           </imports>
       </mxml>
       <binding-value-change-event>org.apache.flex.events.ValueChangeEvent</binding-value-change-event>
@@ -96,6 +96,12 @@
       <binding-value-change-event-type>valueChange</binding-value-change-event-type>
       <binding-event-handler-event>org.apache.flex.events.Event</binding-event-handler-event>
       <binding-event-handler-class>org.apache.flex.events.EventDispatcher</binding-event-handler-class>
+      <states-class>org.apache.flex.states.State</states-class>
+      <states-instance-override-class>org.apache.flex.states.AddItems</states-instance-override-class>
+      <states-property-override-class>org.apache.flex.states.SetProperty</states-property-override-class>
+      <states-event-override-class>org.apache.flex.states.SetEventHandler</states-event-override-class>
+      <component-factory-class>org.apache.flex.core.ClassFactory</component-factory-class>
+      <component-factory-interface>org.apache.flex.core.IFactory</component-factory-interface>
 
       <namespaces>
       <!-- Specify a URI to associate with a manifest of components for use as MXML -->

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/flex-config.xml
----------------------------------------------------------------------
diff --git a/frameworks/flex-config.xml b/frameworks/flex-config.xml
index ddf8b02..27828d2 100644
--- a/frameworks/flex-config.xml
+++ b/frameworks/flex-config.xml
@@ -87,8 +87,8 @@
           <imports>
               <implicit-import>org.apache.flex.events.*</implicit-import>
               <implicit-import>org.apache.flex.geom.*</implicit-import>
-              <implicit-import>mx.core.ClassFactory</implicit-import>
-              <implicit-import>mx.core.IFactory</implicit-import>
+              <implicit-import>org.apache.flex.core.ClassFactory</implicit-import>
+              <implicit-import>org.apache.flex.core.IFactory</implicit-import>
           </imports>
       </mxml>
       <binding-value-change-event>org.apache.flex.events.ValueChangeEvent</binding-value-change-event>
@@ -96,6 +96,12 @@
       <binding-value-change-event-type>valueChange</binding-value-change-event-type>
       <binding-event-handler-event>org.apache.flex.events.Event</binding-event-handler-event>
       <binding-event-handler-class>org.apache.flex.events.EventDispatcher</binding-event-handler-class>
+      <states-class>org.apache.flex.states.State</states-class>
+      <states-instance-override-class>org.apache.flex.states.AddItems</states-instance-override-class>
+      <states-property-override-class>org.apache.flex.states.SetProperty</states-property-override-class>
+      <states-event-override-class>org.apache.flex.states.SetEventHandler</states-event-override-class>
+      <component-factory-class>org.apache.flex.core.ClassFactory</component-factory-class>
+      <component-factory-interface>org.apache.flex.core.IFactory</component-factory-interface>
 
       <namespaces>
       <!-- Specify a URI to associate with a manifest of components for use as MXML -->

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Charts/as/src/org/apache/flex/charts/core/IChartSeries.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Charts/as/src/org/apache/flex/charts/core/IChartSeries.as b/frameworks/projects/Charts/as/src/org/apache/flex/charts/core/IChartSeries.as
index 4c2b1ce..65a2cdb 100644
--- a/frameworks/projects/Charts/as/src/org/apache/flex/charts/core/IChartSeries.as
+++ b/frameworks/projects/Charts/as/src/org/apache/flex/charts/core/IChartSeries.as
@@ -18,7 +18,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 package org.apache.flex.charts.core
 {
-	import mx.core.IFactory;
+	import org.apache.flex.core.IFactory;
 
 	/**
 	 *  The IChartSeries interface is the basic interface for any type of

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/BarSeries.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/BarSeries.as b/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/BarSeries.as
index b45d077..8001b20 100644
--- a/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/BarSeries.as
+++ b/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/BarSeries.as
@@ -18,7 +18,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 package org.apache.flex.charts.supportClasses
 {
-    import mx.core.IFactory;
+    import org.apache.flex.core.IFactory;
     
 	import org.apache.flex.charts.core.IChartSeries;
 	

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/ColumnSeries.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/ColumnSeries.as b/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/ColumnSeries.as
index 58924c6..db91267 100644
--- a/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/ColumnSeries.as
+++ b/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/ColumnSeries.as
@@ -18,7 +18,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 package org.apache.flex.charts.supportClasses
 {
-	import mx.core.IFactory;
+	import org.apache.flex.core.IFactory;
 	
 	import org.apache.flex.charts.core.IChartSeries;
 	

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/LineSeries.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/LineSeries.as b/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/LineSeries.as
index b0b98c2..ca2b62a 100644
--- a/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/LineSeries.as
+++ b/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/LineSeries.as
@@ -18,7 +18,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 package org.apache.flex.charts.supportClasses
 {
-	import mx.core.IFactory;
+	import org.apache.flex.core.IFactory;
 	
 	import org.apache.flex.charts.core.IChartSeries;
 	

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/PieSeries.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/PieSeries.as b/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/PieSeries.as
index e5e5c96..f12df3b 100644
--- a/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/PieSeries.as
+++ b/frameworks/projects/Charts/asjs/src/org/apache/flex/charts/supportClasses/PieSeries.as
@@ -18,7 +18,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 package org.apache.flex.charts.supportClasses
 {
-	import mx.core.IFactory;
+	import org.apache.flex.core.IFactory;
 	
 	import org.apache.flex.charts.core.IChartSeries;
 	

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Charts/js/src/org/apache/flex/charts/core/IChartDataGroup.js
----------------------------------------------------------------------
diff --git a/frameworks/projects/Charts/js/src/org/apache/flex/charts/core/IChartDataGroup.js b/frameworks/projects/Charts/js/src/org/apache/flex/charts/core/IChartDataGroup.js
index 22c4d76..da5bb19 100644
--- a/frameworks/projects/Charts/js/src/org/apache/flex/charts/core/IChartDataGroup.js
+++ b/frameworks/projects/Charts/js/src/org/apache/flex/charts/core/IChartDataGroup.js
@@ -20,7 +20,7 @@
 
 goog.provide('org_apache_flex_charts_core_IChartDataGroup');
 
-goog.require('mx_core_IFactory');
+goog.require('org_apache_flex_core_IFactory');
 goog.require('org_apache_flex_core_IItemRendererParent');
 
 

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Charts/js/src/org/apache/flex/charts/core/IChartSeries.js
----------------------------------------------------------------------
diff --git a/frameworks/projects/Charts/js/src/org/apache/flex/charts/core/IChartSeries.js b/frameworks/projects/Charts/js/src/org/apache/flex/charts/core/IChartSeries.js
index b75086a..90a5649 100644
--- a/frameworks/projects/Charts/js/src/org/apache/flex/charts/core/IChartSeries.js
+++ b/frameworks/projects/Charts/js/src/org/apache/flex/charts/core/IChartSeries.js
@@ -20,7 +20,7 @@
 
 goog.provide('org_apache_flex_charts_core_IChartSeries');
 
-goog.require('mx_core_IFactory');
+goog.require('org_apache_flex_core_IFactory');
 
 
 

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/as/src/CoreClasses.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/as/src/CoreClasses.as b/frameworks/projects/Core/as/src/CoreClasses.as
index b0b7fe8..5e8bafb 100644
--- a/frameworks/projects/Core/as/src/CoreClasses.as
+++ b/frameworks/projects/Core/as/src/CoreClasses.as
@@ -87,11 +87,11 @@ internal class CoreClasses
 	import org.apache.flex.utils.Timer; Timer;
 	import org.apache.flex.utils.UIUtils; UIUtils;
     
-	import mx.core.ClassFactory; ClassFactory;
-    import mx.states.AddItems; AddItems;
-    import mx.states.SetEventHandler; SetEventHandler;
-    import mx.states.SetProperty; SetProperty;
-    import mx.states.State; State;
+	import org.apache.flex.core.ClassFactory; ClassFactory;
+    import org.apache.flex.states.AddItems; AddItems;
+    import org.apache.flex.states.SetEventHandler; SetEventHandler;
+    import org.apache.flex.states.SetProperty; SetProperty;
+    import org.apache.flex.states.State; State;
 }
 
 }

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/as/src/org/apache/flex/core/ClassFactory.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/as/src/org/apache/flex/core/ClassFactory.as b/frameworks/projects/Core/as/src/org/apache/flex/core/ClassFactory.as
index 5c0964c..8b1f254 100644
--- a/frameworks/projects/Core/as/src/org/apache/flex/core/ClassFactory.as
+++ b/frameworks/projects/Core/as/src/org/apache/flex/core/ClassFactory.as
@@ -16,9 +16,9 @@
 //  limitations under the License.
 //
 ////////////////////////////////////////////////////////////////////////////////
-package mx.core
+package org.apache.flex.core
 {
-	import mx.core.IFactory;
+	import org.apache.flex.core.IFactory;
 	
     /**
      *  The ClassFactory class is the basic implementation
@@ -66,7 +66,7 @@ package mx.core
 		}
 		
         /**
-         *  @copy mx.core.IFactory#newInstance()
+         *  @copy score.IFactory#newInstance()
          *  
          *  @langversion 3.0
          *  @playerversion Flash 9

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/as/src/org/apache/flex/core/ContainerBase.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/as/src/org/apache/flex/core/ContainerBase.as b/frameworks/projects/Core/as/src/org/apache/flex/core/ContainerBase.as
index ab31e43..daeeae6 100644
--- a/frameworks/projects/Core/as/src/org/apache/flex/core/ContainerBase.as
+++ b/frameworks/projects/Core/as/src/org/apache/flex/core/ContainerBase.as
@@ -18,7 +18,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 package org.apache.flex.core
 {
-	import mx.states.State;
+	import org.apache.flex.states.State;
 	
 	import org.apache.flex.core.IMXMLDocument;
     import org.apache.flex.core.ValuesManager;
@@ -170,7 +170,7 @@ package org.apache.flex.core
         
         /**
          *  The array of view states. These should
-         *  be instances of mx.states.State.
+         *  be instances of org.apache.flex.states.State.
          *  
          *  @langversion 3.0
          *  @playerversion Flash 10.2

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/as/src/org/apache/flex/core/IFactory.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/as/src/org/apache/flex/core/IFactory.as b/frameworks/projects/Core/as/src/org/apache/flex/core/IFactory.as
index aaac8e3..36c0841 100644
--- a/frameworks/projects/Core/as/src/org/apache/flex/core/IFactory.as
+++ b/frameworks/projects/Core/as/src/org/apache/flex/core/IFactory.as
@@ -16,7 +16,7 @@
 //  limitations under the License.
 //
 ////////////////////////////////////////////////////////////////////////////////
-package mx.core
+package org.apache.flex.core
 {
     /**
      *  The IFactory interface is the basic interface used as the 

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/as/src/org/apache/flex/core/IItemRendererClassFactory.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/as/src/org/apache/flex/core/IItemRendererClassFactory.as b/frameworks/projects/Core/as/src/org/apache/flex/core/IItemRendererClassFactory.as
index c1fccc4..36e9d9f 100644
--- a/frameworks/projects/Core/as/src/org/apache/flex/core/IItemRendererClassFactory.as
+++ b/frameworks/projects/Core/as/src/org/apache/flex/core/IItemRendererClassFactory.as
@@ -21,7 +21,7 @@ package org.apache.flex.core
     /**
      *  The IItemRendererClassFactory interface is the basic interface for beads
      *  that generate instances of IItemRenderers.  Note that this is not the same
-     *  as an mx.core.IFactory which is a lower-level interface for generating
+     *  as an org.apache.flex.core.IFactory which is a lower-level interface for generating
      *  an instance of just about anything.  IItemRendererClassFactory implementations
      *  often use IFactory to generate the actual item renderer instance, but
      *  the IItemRendererClassFactory bead allows for more computation about which 

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/as/src/org/apache/flex/core/IStatesObject.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/as/src/org/apache/flex/core/IStatesObject.as b/frameworks/projects/Core/as/src/org/apache/flex/core/IStatesObject.as
index be11ac7..1432e35 100644
--- a/frameworks/projects/Core/as/src/org/apache/flex/core/IStatesObject.as
+++ b/frameworks/projects/Core/as/src/org/apache/flex/core/IStatesObject.as
@@ -33,7 +33,7 @@ package org.apache.flex.core
 	{
         /**
          *  The array of view states. These should
-         *  be instances of mx.states.State.
+         *  be instances of org.apache.flex.states.State.
          *  
          *  @langversion 3.0
          *  @playerversion Flash 10.2

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/as/src/org/apache/flex/core/ItemRendererClassFactory.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/as/src/org/apache/flex/core/ItemRendererClassFactory.as b/frameworks/projects/Core/as/src/org/apache/flex/core/ItemRendererClassFactory.as
index 96bd5a9..b2a7ef3 100644
--- a/frameworks/projects/Core/as/src/org/apache/flex/core/ItemRendererClassFactory.as
+++ b/frameworks/projects/Core/as/src/org/apache/flex/core/ItemRendererClassFactory.as
@@ -19,8 +19,8 @@
 package org.apache.flex.core
 {
     
-    import mx.core.ClassFactory;
-    import mx.core.IFactory;
+    import org.apache.flex.core.ClassFactory;
+    import org.apache.flex.core.IFactory;
     
     import org.apache.flex.utils.MXMLDataInterpreter;
 

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/as/src/org/apache/flex/core/SimpleStatesImpl.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/as/src/org/apache/flex/core/SimpleStatesImpl.as b/frameworks/projects/Core/as/src/org/apache/flex/core/SimpleStatesImpl.as
index 34f27e9..e0982ed 100644
--- a/frameworks/projects/Core/as/src/org/apache/flex/core/SimpleStatesImpl.as
+++ b/frameworks/projects/Core/as/src/org/apache/flex/core/SimpleStatesImpl.as
@@ -20,10 +20,10 @@ package org.apache.flex.core
 {
     import flash.display.DisplayObject;
     
-    import mx.states.AddItems;
-    import mx.states.SetEventHandler;
-    import mx.states.SetProperty;
-    import mx.states.State;
+    import org.apache.flex.states.AddItems;
+    import org.apache.flex.states.SetEventHandler;
+    import org.apache.flex.states.SetProperty;
+    import org.apache.flex.states.State;
     
     import org.apache.flex.core.IParent;
     import org.apache.flex.core.IStatesObject;

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/as/src/org/apache/flex/states/AddItems.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/as/src/org/apache/flex/states/AddItems.as b/frameworks/projects/Core/as/src/org/apache/flex/states/AddItems.as
index 99777cb..1c26fd5 100644
--- a/frameworks/projects/Core/as/src/org/apache/flex/states/AddItems.as
+++ b/frameworks/projects/Core/as/src/org/apache/flex/states/AddItems.as
@@ -20,7 +20,7 @@
 // shim the mx classes for states.  Be careful about updates to the main SDK's
 // version as that will move the timestamp ahead of this one and then it will
 // take precedence over this one at link time.
-package mx.states
+package org.apache.flex.states
 {
     import org.apache.flex.core.IDocument;
     

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/as/src/org/apache/flex/states/ItemAndDescriptor.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/as/src/org/apache/flex/states/ItemAndDescriptor.as b/frameworks/projects/Core/as/src/org/apache/flex/states/ItemAndDescriptor.as
index e704917..58621f9 100644
--- a/frameworks/projects/Core/as/src/org/apache/flex/states/ItemAndDescriptor.as
+++ b/frameworks/projects/Core/as/src/org/apache/flex/states/ItemAndDescriptor.as
@@ -17,7 +17,7 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-package mx.states
+package org.apache.flex.states
 {
     
     [ExcludeClass]

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/as/src/org/apache/flex/states/SetEventHandler.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/as/src/org/apache/flex/states/SetEventHandler.as b/frameworks/projects/Core/as/src/org/apache/flex/states/SetEventHandler.as
index 95246a0..035309b 100644
--- a/frameworks/projects/Core/as/src/org/apache/flex/states/SetEventHandler.as
+++ b/frameworks/projects/Core/as/src/org/apache/flex/states/SetEventHandler.as
@@ -17,7 +17,7 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 // shim the mx classes for states
-package mx.states
+package org.apache.flex.states
 {
     import org.apache.flex.core.IDocument;
     

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/as/src/org/apache/flex/states/SetProperty.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/as/src/org/apache/flex/states/SetProperty.as b/frameworks/projects/Core/as/src/org/apache/flex/states/SetProperty.as
index 595f84a..56ba67c 100644
--- a/frameworks/projects/Core/as/src/org/apache/flex/states/SetProperty.as
+++ b/frameworks/projects/Core/as/src/org/apache/flex/states/SetProperty.as
@@ -17,7 +17,7 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 // shim the mx classes for states
-package mx.states
+package org.apache.flex.states
 {
     import org.apache.flex.core.IDocument;
     

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/as/src/org/apache/flex/states/State.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/as/src/org/apache/flex/states/State.as b/frameworks/projects/Core/as/src/org/apache/flex/states/State.as
index 3c08d57..dc620d1 100644
--- a/frameworks/projects/Core/as/src/org/apache/flex/states/State.as
+++ b/frameworks/projects/Core/as/src/org/apache/flex/states/State.as
@@ -18,7 +18,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 // shim the mx classes for states
-package mx.states
+package org.apache.flex.states
 {
     /**
      *  The State class is one of the classes in the

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/basic-manifest.xml
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/basic-manifest.xml b/frameworks/projects/Core/basic-manifest.xml
index 8d9a3e0..ac43d5e 100644
--- a/frameworks/projects/Core/basic-manifest.xml
+++ b/frameworks/projects/Core/basic-manifest.xml
@@ -33,5 +33,7 @@
     <component id="ParentDocumentBead" class="org.apache.flex.core.ParentDocumentBead"/>
     <component id="MixinManager" class="org.apache.flex.utils.MixinManager" />
     <component id="ViewSourceContextMenuOption" class="org.apache.flex.utils.ViewSourceContextMenuOption" />
-
+    
+    <component id="State" class="org.apache.flex.states.State"/>
+    
 </componentPackage>

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/compile-config.xml
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/compile-config.xml b/frameworks/projects/Core/compile-config.xml
index 718bf56..7061e26 100644
--- a/frameworks/projects/Core/compile-config.xml
+++ b/frameworks/projects/Core/compile-config.xml
@@ -49,10 +49,6 @@
                 <uri>library://ns.apache.org/flexjs/basic</uri>
                 <manifest>basic-manifest.xml</manifest>
             </namespace>
-            <namespace>
-                <uri>library://ns.adobe.com/flex/mx</uri>
-                <manifest>mx-manifest.xml</manifest>
-            </namespace>
         </namespaces>
         
         <source-path>
@@ -79,7 +75,6 @@
     
     <include-namespaces>
         <uri>library://ns.apache.org/flexjs/basic</uri>
-        <uri>library://ns.adobe.com/flex/mx</uri>
 		<uri>library://ns.apache.org/flexjs/svg</uri>
     </include-namespaces>  
         

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/js/src/org/apache/flex/core/ClassFactory.js
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/js/src/org/apache/flex/core/ClassFactory.js b/frameworks/projects/Core/js/src/org/apache/flex/core/ClassFactory.js
index 97fec5c..240b5b4 100644
--- a/frameworks/projects/Core/js/src/org/apache/flex/core/ClassFactory.js
+++ b/frameworks/projects/Core/js/src/org/apache/flex/core/ClassFactory.js
@@ -12,18 +12,18 @@
  * limitations under the License.
  */
 
-goog.provide('mx_core_ClassFactory');
+goog.provide('org_apache_flex_core_ClassFactory');
 
-goog.require('mx_core_IFactory');
+goog.require('org_apache_flex_core_IFactory');
 
 
 
 /**
  * @constructor
- * @implements {mx_core_IFactory}
+ * @implements {org_apache_flex_core_IFactory}
  * @param {Function} generator The class definition to use for newInstance.
  */
-mx_core_ClassFactory = function(generator) {
+org_apache_flex_core_ClassFactory = function(generator) {
   /**
    * @private
    * @type {Function}
@@ -38,18 +38,18 @@ mx_core_ClassFactory = function(generator) {
  *
  * @type {Object.<string, Array.<Object>>}
  */
-mx_core_ClassFactory.prototype.
+org_apache_flex_core_ClassFactory.prototype.
     FLEXJS_CLASS_INFO =
         { names: [{ name: 'ClassFactory',
-           qName: 'mx_core_ClassFactory' }],
-    interfaces: [mx_core_IFactory] };
+           qName: 'org_apache_flex_core_ClassFactory' }],
+    interfaces: [org_apache_flex_core_IFactory] };
 
 
 /**
  * @expose
  * @return {Object} The new instance of the class described by generator.
  */
-mx_core_ClassFactory.
+org_apache_flex_core_ClassFactory.
     prototype.newInstance = function() {
   var obj = new this.generator_();
 

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/js/src/org/apache/flex/core/IFactory.js
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/js/src/org/apache/flex/core/IFactory.js b/frameworks/projects/Core/js/src/org/apache/flex/core/IFactory.js
index 556a4e0..036f702 100644
--- a/frameworks/projects/Core/js/src/org/apache/flex/core/IFactory.js
+++ b/frameworks/projects/Core/js/src/org/apache/flex/core/IFactory.js
@@ -17,14 +17,14 @@
  * @suppress {checkTypes}
  */
 
-goog.provide('mx_core_IFactory');
+goog.provide('org_apache_flex_core_IFactory');
 
 
 
 /**
  * @interface
  */
-mx_core_IFactory = function() {
+org_apache_flex_core_IFactory = function() {
 };
 
 
@@ -32,7 +32,7 @@ mx_core_IFactory = function() {
  * @expose
  * @return {Object} A new instance of the itemRenderer.
  */
-mx_core_IFactory.prototype.newInstance = function() {};
+org_apache_flex_core_IFactory.prototype.newInstance = function() {};
 
 
 /**
@@ -40,6 +40,6 @@ mx_core_IFactory.prototype.newInstance = function() {};
  *
  * @type {Object.<string, Array.<Object>>}
  */
-mx_core_IFactory.prototype.FLEXJS_CLASS_INFO =
+org_apache_flex_core_IFactory.prototype.FLEXJS_CLASS_INFO =
     { names: [{ name: 'IFactory',
-                qName: 'mx_core_IFactory' }] };
+                qName: 'org_apache_flex_core_IFactory' }] };

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/js/src/org/apache/flex/core/ItemRendererClassFactory.js
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/js/src/org/apache/flex/core/ItemRendererClassFactory.js b/frameworks/projects/Core/js/src/org/apache/flex/core/ItemRendererClassFactory.js
index 84b16c4..2693ab0 100644
--- a/frameworks/projects/Core/js/src/org/apache/flex/core/ItemRendererClassFactory.js
+++ b/frameworks/projects/Core/js/src/org/apache/flex/core/ItemRendererClassFactory.js
@@ -14,7 +14,7 @@
 
 goog.provide('org_apache_flex_core_ItemRendererClassFactory');
 
-goog.require('mx_core_ClassFactory');
+goog.require('org_apache_flex_core_ClassFactory');
 goog.require('org_apache_flex_core_IItemRendererClassFactory');
 goog.require('org_apache_flex_core_ValuesManager');
 
@@ -66,7 +66,7 @@ Object.defineProperties(org_apache_flex_core_ItemRendererClassFactory.prototype,
               /** @type {Function} */ (org_apache_flex_core_ValuesManager.valuesImpl.
                   getValue(this.strand_, 'iItemRenderer'));
               if (this.itemRendererClass) {
-                this.itemRendererClassFactory = new mx_core_ClassFactory(this.itemRendererClass);
+                this.itemRendererClassFactory = new org_apache_flex_core_ClassFactory(this.itemRendererClass);
                 this.createFunction = this.createFromClass;
               }
            }

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/js/src/org/apache/flex/core/SimpleStatesImpl.js
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/js/src/org/apache/flex/states/AddItems.js b/frameworks/projects/Core/js/src/org/apache/flex/states/AddItems.js
index 22f7619..c3e4da7 100644
--- a/frameworks/projects/Core/js/src/org/apache/flex/states/AddItems.js
+++ b/frameworks/projects/Core/js/src/org/apache/flex/states/AddItems.js
@@ -12,7 +12,7 @@
  * limitations under the License.
  */
 
-goog.provide('mx_states_AddItems');
+goog.provide('org_apache_flex_states_AddItems');
 
 goog.require('org_apache_flex_core_IDocument');
 
@@ -22,7 +22,7 @@ goog.require('org_apache_flex_core_IDocument');
  * @constructor
  * @implements {org_apache_flex_core_IDocument}
  */
-mx_states_AddItems = function() {
+org_apache_flex_states_AddItems = function() {
 };
 
 
@@ -31,9 +31,9 @@ mx_states_AddItems = function() {
  *
  * @type {Object.<string, Array.<Object>>}
  */
-mx_states_AddItems.prototype.FLEXJS_CLASS_INFO =
+org_apache_flex_states_AddItems.prototype.FLEXJS_CLASS_INFO =
     { names: [{ name: 'AddItems',
-                qName: 'mx_states_AddItems' }],
+                qName: 'org_apache_flex_states_AddItems' }],
       interfaces: [org_apache_flex_core_IDocument] };
 
 
@@ -41,7 +41,7 @@ mx_states_AddItems.prototype.FLEXJS_CLASS_INFO =
  * @param {Object} document The MXML object.
  * @param {?string=} opt_id The id.
  */
-mx_states_AddItems.prototype.setDocument = function(document, opt_id) {
+org_apache_flex_states_AddItems.prototype.setDocument = function(document, opt_id) {
   opt_id = typeof opt_id !== 'undefined' ? opt_id : null;
   this.document = document;
   var data = document['mxmlsd'][this.itemsDescriptorIndex];
@@ -60,14 +60,14 @@ mx_states_AddItems.prototype.setDocument = function(document, opt_id) {
  * @expose
  * @type {Object} document The MXML object.
  */
-mx_states_AddItems.prototype.document = null;
+org_apache_flex_states_AddItems.prototype.document = null;
 
 
 /**
  * @expose
  * @type {Array} items The array of items to add.
  */
-mx_states_AddItems.prototype.items = null;
+org_apache_flex_states_AddItems.prototype.items = null;
 
 
 /**
@@ -75,42 +75,42 @@ mx_states_AddItems.prototype.items = null;
  * @type {number} itemsDescriptor The index into the array
  *                               of itemDescriptors on the document
  */
-mx_states_AddItems.prototype.itemsDescriptorIndex = -1;
+org_apache_flex_states_AddItems.prototype.itemsDescriptorIndex = -1;
 
 
 /**
  * @expose
  * @type {Object} itemsDescriptor The descriptors for items.
  */
-mx_states_AddItems.prototype.itemsDescriptor = null;
+org_apache_flex_states_AddItems.prototype.itemsDescriptor = null;
 
 
 /**
  * @expose
  * @type {string} destination The id of the parent.
  */
-mx_states_AddItems.prototype.destination = '';
+org_apache_flex_states_AddItems.prototype.destination = '';
 
 
 /**
  * @expose
  * @type {string} propertyName The child property name (e.g. mxmlContent).
  */
-mx_states_AddItems.prototype.propertyName = '';
+org_apache_flex_states_AddItems.prototype.propertyName = '';
 
 
 /**
  * @expose
  * @type {string} position Where the item goes relative to relativeTo.
  */
-mx_states_AddItems.prototype.position = '';
+org_apache_flex_states_AddItems.prototype.position = '';
 
 
 /**
  * @expose
  * @type {?string} relativeTo The id of the child where the item goes.
  */
-mx_states_AddItems.prototype.relativeTo = null;
+org_apache_flex_states_AddItems.prototype.relativeTo = null;
 
 
 /**
@@ -118,7 +118,7 @@ mx_states_AddItems.prototype.relativeTo = null;
  * @param {Object} properties The properties for the new object.
  * @return {Object} The new object.
  */
-mx_states_AddItems.prototype.initializeFromObject = function(properties) {
+org_apache_flex_states_AddItems.prototype.initializeFromObject = function(properties) {
   var p;
 
   for (p in properties) {

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/js/src/org/apache/flex/states/SetEventHandler.js
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/js/src/org/apache/flex/states/SetEventHandler.js b/frameworks/projects/Core/js/src/org/apache/flex/states/SetEventHandler.js
index 1edc36e..033d73c 100644
--- a/frameworks/projects/Core/js/src/org/apache/flex/states/SetEventHandler.js
+++ b/frameworks/projects/Core/js/src/org/apache/flex/states/SetEventHandler.js
@@ -12,7 +12,7 @@
  * limitations under the License.
  */
 
-goog.provide('mx_states_SetEventHandler');
+goog.provide('org_apache_flex_states_SetEventHandler');
 
 goog.require('org_apache_flex_core_IDocument');
 
@@ -22,7 +22,7 @@ goog.require('org_apache_flex_core_IDocument');
  * @constructor
  * @implements {org_apache_flex_core_IDocument}
  */
-mx_states_SetEventHandler = function() {
+org_apache_flex_states_SetEventHandler = function() {
 };
 
 
@@ -31,9 +31,9 @@ mx_states_SetEventHandler = function() {
  *
  * @type {Object.<string, Array.<Object>>}
  */
-mx_states_SetEventHandler.prototype.FLEXJS_CLASS_INFO =
+org_apache_flex_states_SetEventHandler.prototype.FLEXJS_CLASS_INFO =
     { names: [{ name: 'SetEventHandler',
-                qName: 'mx_states_SetEventHandler' }],
+                qName: 'org_apache_flex_states_SetEventHandler' }],
       interfaces: [org_apache_flex_core_IDocument] };
 
 
@@ -41,7 +41,7 @@ mx_states_SetEventHandler.prototype.FLEXJS_CLASS_INFO =
  * @param {Object} document The MXML object.
  * @param {?string=} opt_id The id.
  */
-mx_states_SetEventHandler.prototype.setDocument = function(document, opt_id) {
+org_apache_flex_states_SetEventHandler.prototype.setDocument = function(document, opt_id) {
   opt_id = typeof opt_id !== 'undefined' ? opt_id : null;
   this.document = document;
 };
@@ -51,28 +51,28 @@ mx_states_SetEventHandler.prototype.setDocument = function(document, opt_id) {
  * @expose
  * @type {Object} document The MXML object.
  */
-mx_states_SetEventHandler.prototype.document = null;
+org_apache_flex_states_SetEventHandler.prototype.document = null;
 
 
 /**
  * @expose
  * @type {string} name The event to listen for.
  */
-mx_states_SetEventHandler.prototype.name = '';
+org_apache_flex_states_SetEventHandler.prototype.name = '';
 
 
 /**
  * @expose
  * @type {string} target The id of the object.
  */
-mx_states_SetEventHandler.prototype.target = '';
+org_apache_flex_states_SetEventHandler.prototype.target = '';
 
 
 /**
  * @expose
  * @type {Object} handlerFunction The listener to be added.
  */
-mx_states_SetEventHandler.prototype.handlerFunction = null;
+org_apache_flex_states_SetEventHandler.prototype.handlerFunction = null;
 
 
 /**
@@ -80,7 +80,7 @@ mx_states_SetEventHandler.prototype.handlerFunction = null;
  * @param {Object} properties The properties for the new object.
  * @return {Object} The new object.
  */
-mx_states_SetEventHandler.prototype.initializeFromObject = function(properties) {
+org_apache_flex_states_SetEventHandler.prototype.initializeFromObject = function(properties) {
   var p;
 
   for (p in properties) {

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/js/src/org/apache/flex/states/SetProperty.js
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/js/src/org/apache/flex/states/SetProperty.js b/frameworks/projects/Core/js/src/org/apache/flex/states/SetProperty.js
index f7feca9..88541f1 100644
--- a/frameworks/projects/Core/js/src/org/apache/flex/states/SetProperty.js
+++ b/frameworks/projects/Core/js/src/org/apache/flex/states/SetProperty.js
@@ -12,7 +12,7 @@
  * limitations under the License.
  */
 
-goog.provide('mx_states_SetProperty');
+goog.provide('org_apache_flex_states_SetProperty');
 
 goog.require('org_apache_flex_core_IDocument');
 
@@ -22,7 +22,7 @@ goog.require('org_apache_flex_core_IDocument');
  * @constructor
  * @implements {org_apache_flex_core_IDocument}
  */
-mx_states_SetProperty = function() {
+org_apache_flex_states_SetProperty = function() {
 };
 
 
@@ -31,9 +31,9 @@ mx_states_SetProperty = function() {
  *
  * @type {Object.<string, Array.<Object>>}
  */
-mx_states_SetProperty.prototype.FLEXJS_CLASS_INFO =
+org_apache_flex_states_SetProperty.prototype.FLEXJS_CLASS_INFO =
     { names: [{ name: 'SetProperty',
-                qName: 'mx_states_SetProperty' }],
+                qName: 'org_apache_flex_states_SetProperty' }],
       interfaces: [org_apache_flex_core_IDocument] };
 
 
@@ -41,7 +41,7 @@ mx_states_SetProperty.prototype.FLEXJS_CLASS_INFO =
  * @param {Object} document The MXML object.
  * @param {?string=} opt_id The id.
  */
-mx_states_SetProperty.prototype.setDocument = function(document, opt_id) {
+org_apache_flex_states_SetProperty.prototype.setDocument = function(document, opt_id) {
   opt_id = typeof opt_id !== 'undefined' ? opt_id : null;
   this.document = document;
 };
@@ -51,35 +51,35 @@ mx_states_SetProperty.prototype.setDocument = function(document, opt_id) {
  * @expose
  * @type {Object} document The MXML object.
  */
-mx_states_SetProperty.prototype.document = null;
+org_apache_flex_states_SetProperty.prototype.document = null;
 
 
 /**
  * @expose
  * @type {string} name The target property name.
  */
-mx_states_SetProperty.prototype.name = '';
+org_apache_flex_states_SetProperty.prototype.name = '';
 
 
 /**
  * @expose
  * @type {?string} target The id of the object.
  */
-mx_states_SetProperty.prototype.target = null;
+org_apache_flex_states_SetProperty.prototype.target = null;
 
 
 /**
  * @expose
  * @type {Object} previousValue The value to revert to.
  */
-mx_states_SetProperty.prototype.previousValue = null;
+org_apache_flex_states_SetProperty.prototype.previousValue = null;
 
 
 /**
  * @expose
  * @type {Object} value The value to set.
  */
-mx_states_SetProperty.prototype.value = null;
+org_apache_flex_states_SetProperty.prototype.value = null;
 
 
 /**
@@ -87,7 +87,7 @@ mx_states_SetProperty.prototype.value = null;
  * @param {Object} properties The properties for the new object.
  * @return {Object} The new object.
  */
-mx_states_SetProperty.prototype.initializeFromObject = function(properties) {
+org_apache_flex_states_SetProperty.prototype.initializeFromObject = function(properties) {
   var p;
 
   for (p in properties) {

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/js/src/org/apache/flex/states/State.js
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/js/src/org/apache/flex/states/State.js b/frameworks/projects/Core/js/src/org/apache/flex/states/State.js
index 0d6df35..2bd1f18 100644
--- a/frameworks/projects/Core/js/src/org/apache/flex/states/State.js
+++ b/frameworks/projects/Core/js/src/org/apache/flex/states/State.js
@@ -12,7 +12,7 @@
  * limitations under the License.
  */
 
-goog.provide('mx_states_State');
+goog.provide('org_apache_flex_states_State');
 
 
 
@@ -20,7 +20,7 @@ goog.provide('mx_states_State');
  * @constructor
  * @param {Object=} opt_props The initial properties.
  */
-mx_states_State = function(opt_props) {
+org_apache_flex_states_State = function(opt_props) {
   opt_props = typeof opt_props !== 'undefined' ? opt_props : null;
 };
 
@@ -30,20 +30,20 @@ mx_states_State = function(opt_props) {
  *
  * @type {Object.<string, Array.<Object>>}
  */
-mx_states_State.prototype.FLEXJS_CLASS_INFO =
+org_apache_flex_states_State.prototype.FLEXJS_CLASS_INFO =
     { names: [{ name: 'State',
-                qName: 'mx_states_State' }] };
+                qName: 'org_apache_flex_states_State' }] };
 
 
 /**
  * @expose
  * @type {string} name The state name.
  */
-mx_states_State.prototype.name = '';
+org_apache_flex_states_State.prototype.name = '';
 
 
 /**
  * @expose
  * @type {Array} overrides The state data.
  */
-mx_states_State.prototype.overrides = null;
+org_apache_flex_states_State.prototype.overrides = null;

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/mx-manifest.xml
----------------------------------------------------------------------
diff --git a/frameworks/projects/Core/mx-manifest.xml b/frameworks/projects/Core/mx-manifest.xml
deleted file mode 100644
index 6654ace..0000000
--- a/frameworks/projects/Core/mx-manifest.xml
+++ /dev/null
@@ -1,26 +0,0 @@
-<?xml version="1.0"?>
-<!--
-
-  Licensed to the Apache Software Foundation (ASF) under one or more
-  contributor license agreements.  See the NOTICE file distributed with
-  this work for additional information regarding copyright ownership.
-  The ASF licenses this file to You under the Apache License, Version 2.0
-  (the "License"); you may not use this file except in compliance with
-  the License.  You may obtain a copy of the License at
-
-      http://www.apache.org/licenses/LICENSE-2.0
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
--->
-
-
-<componentPackage>
-
-    <component id="State" class="mx.states.State"/>
-
-</componentPackage>

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Effects/asjs/src/org/apache/flex/core/StatesWithTransitionsImpl.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Effects/asjs/src/org/apache/flex/core/StatesWithTransitionsImpl.as b/frameworks/projects/Effects/asjs/src/org/apache/flex/core/StatesWithTransitionsImpl.as
index d0e9059..3e72d43 100644
--- a/frameworks/projects/Effects/asjs/src/org/apache/flex/core/StatesWithTransitionsImpl.as
+++ b/frameworks/projects/Effects/asjs/src/org/apache/flex/core/StatesWithTransitionsImpl.as
@@ -19,10 +19,10 @@
 package org.apache.flex.core
 {
     
-    import mx.states.AddItems;
-    import mx.states.SetEventHandler;
-    import mx.states.SetProperty;
-    import mx.states.State;
+    import org.apache.flex.states.AddItems;
+    import org.apache.flex.states.SetEventHandler;
+    import org.apache.flex.states.SetProperty;
+    import org.apache.flex.states.State;
     
     import org.apache.flex.core.IParent;
     import org.apache.flex.core.IStatesObject;

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Effects/asjs/src/org/apache/flex/effects/Tween.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/Effects/asjs/src/org/apache/flex/effects/Tween.as b/frameworks/projects/Effects/asjs/src/org/apache/flex/effects/Tween.as
index 979154d..3b9415e 100644
--- a/frameworks/projects/Effects/asjs/src/org/apache/flex/effects/Tween.as
+++ b/frameworks/projects/Effects/asjs/src/org/apache/flex/effects/Tween.as
@@ -75,9 +75,9 @@ public class Tween extends Effect
 	 *       <code>onTweenEnd()</code> method.</td></tr>
 	 *  </table>
 	 *
-	 *  @see mx.effects.Effect
-	 *  @see mx.effects.TweenEffect 
-	 *  @see mx.events.EffectEvent
+	 *  @see org.apache.flex.effects.Effect
+	 *  @see org.apache.flex.effects.TweenEffect 
+	 *  @see org.apache.flex.events.EffectEvent
 	 *  @eventType tweenEnd 
 	 *  
 	 *  @langversion 3.0

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/HTML/as/src/org/apache/flex/html/List.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/HTML/as/src/org/apache/flex/html/List.as b/frameworks/projects/HTML/as/src/org/apache/flex/html/List.as
index 856d37b..39706a0 100644
--- a/frameworks/projects/HTML/as/src/org/apache/flex/html/List.as
+++ b/frameworks/projects/HTML/as/src/org/apache/flex/html/List.as
@@ -18,7 +18,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 package org.apache.flex.html
 {
-	import mx.core.IFactory;
+	import org.apache.flex.core.IFactory;
 	
 	import org.apache.flex.core.IDataProviderItemRendererMapper;
 	import org.apache.flex.core.IItemRendererClassFactory;

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/HTML/asjs/src/org/apache/flex/html/MXMLBeadViewBase.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/HTML/asjs/src/org/apache/flex/html/MXMLBeadViewBase.as b/frameworks/projects/HTML/asjs/src/org/apache/flex/html/MXMLBeadViewBase.as
index c1a1fdf..5a15183 100644
--- a/frameworks/projects/HTML/asjs/src/org/apache/flex/html/MXMLBeadViewBase.as
+++ b/frameworks/projects/HTML/asjs/src/org/apache/flex/html/MXMLBeadViewBase.as
@@ -18,7 +18,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 package org.apache.flex.html
 {
-	import mx.states.State;
+	import org.apache.flex.states.State;
 	
 	import org.apache.flex.core.IBead;
     import org.apache.flex.core.ILayoutParent;
@@ -147,7 +147,7 @@ package org.apache.flex.html
         
         /**
          *  The array of view states. These should
-         *  be instances of mx.states.State.
+         *  be instances of org.apache.flex.states.State.
          *  
          *  @langversion 3.0
          *  @playerversion Flash 10.2

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/HTML/asjs/src/org/apache/flex/html/supportClasses/DataGridColumn.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/HTML/asjs/src/org/apache/flex/html/supportClasses/DataGridColumn.as b/frameworks/projects/HTML/asjs/src/org/apache/flex/html/supportClasses/DataGridColumn.as
index 927da73..24e16fd 100644
--- a/frameworks/projects/HTML/asjs/src/org/apache/flex/html/supportClasses/DataGridColumn.as
+++ b/frameworks/projects/HTML/asjs/src/org/apache/flex/html/supportClasses/DataGridColumn.as
@@ -18,7 +18,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 package org.apache.flex.html.supportClasses
 {
-	import mx.core.IFactory;
+	import org.apache.flex.core.IFactory;
 
 	/**
 	 *  The DataGridColumn class is the collection of properties that describe

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/HTML/js/src/org/apache/flex/html/List.js
----------------------------------------------------------------------
diff --git a/frameworks/projects/HTML/js/src/org/apache/flex/html/List.js b/frameworks/projects/HTML/js/src/org/apache/flex/html/List.js
index 6db743e..a60245f 100644
--- a/frameworks/projects/HTML/js/src/org/apache/flex/html/List.js
+++ b/frameworks/projects/HTML/js/src/org/apache/flex/html/List.js
@@ -14,8 +14,8 @@
 
 goog.provide('org_apache_flex_html_List');
 
-goog.require('mx_core_IFactory');
 goog.require('org_apache_flex_core_IDataProviderItemRendererMapper');
+goog.require('org_apache_flex_core_IFactory');
 goog.require('org_apache_flex_core_IItemRendererClassFactory');
 goog.require('org_apache_flex_core_IListPresentationModel');
 goog.require('org_apache_flex_core_ItemRendererClassFactory');

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/HTML/js/src/org/apache/flex/html/supportClasses/DataGridColumn.js
----------------------------------------------------------------------
diff --git a/frameworks/projects/HTML/js/src/org/apache/flex/html/supportClasses/DataGridColumn.js b/frameworks/projects/HTML/js/src/org/apache/flex/html/supportClasses/DataGridColumn.js
index 84959e7..218f067 100644
--- a/frameworks/projects/HTML/js/src/org/apache/flex/html/supportClasses/DataGridColumn.js
+++ b/frameworks/projects/HTML/js/src/org/apache/flex/html/supportClasses/DataGridColumn.js
@@ -14,7 +14,7 @@
 
 goog.provide('org_apache_flex_html_supportClasses_DataGridColumn');
 
-goog.require('mx_core_IFactory');
+goog.require('org_apache_flex_core_IFactory');
diff --git a/frameworks/projects/Core/js/src/org/apache/flex/core/SimpleStatesImpl.js b/frameworks/projects/Core/js/src/org/apache/flex/core/SimpleStatesImpl.js
index 34ecf93..2499cd6 100644
--- a/frameworks/projects/Core/js/src/org/apache/flex/core/SimpleStatesImpl.js
+++ b/frameworks/projects/Core/js/src/org/apache/flex/core/SimpleStatesImpl.js
@@ -14,15 +14,15 @@
 
 goog.provide('org_apache_flex_core_SimpleStatesImpl');
 
-goog.require('mx_states_AddItems');
-goog.require('mx_states_SetEventHandler');
-goog.require('mx_states_SetProperty');
-goog.require('mx_states_State');
 goog.require('org_apache_flex_core_IBead');
 goog.require('org_apache_flex_core_IStatesImpl');
 goog.require('org_apache_flex_core_IStrand');
 goog.require('org_apache_flex_core_UIBase');
 goog.require('org_apache_flex_events_EventDispatcher');
+goog.require('org_apache_flex_states_AddItems');
+goog.require('org_apache_flex_states_SetEventHandler');
+goog.require('org_apache_flex_states_SetProperty');
+goog.require('org_apache_flex_states_State');
 
 
 
@@ -122,7 +122,7 @@ org_apache_flex_core_SimpleStatesImpl.prototype.stateChangeHandler_ =
 
 /**
  * @private
  * @param {mx_states_State} s The State to revert.
  */
 org_apache_flex_core_SimpleStatesImpl.prototype.revert_ = function(s) {
   var arr, item, o, p, q, target;
@@ -133,7 +133,7 @@ org_apache_flex_core_SimpleStatesImpl.prototype.revert_ = function(s) {
   arr = s.overrides;
   for (p in arr) {
     o = arr[p];
-    if (org_apache_flex_utils_Language.is(o, mx_states_AddItems)) {
+    if (org_apache_flex_utils_Language.is(o, org_apache_flex_states_AddItems)) {
       for (q in o.items) {
         item = o.items[q];
 
@@ -146,10 +146,10 @@ org_apache_flex_core_SimpleStatesImpl.prototype.revert_ = function(s) {
         parent.dispatchEvent(
             new org_apache_flex_events_Event('childrenAdded'));
       }
-    } else if (org_apache_flex_utils_Language.is(o, mx_states_SetProperty)) {
+    } else if (org_apache_flex_utils_Language.is(o, org_apache_flex_states_SetProperty)) {
       target = o.document[o.target];
       target[o.name] = o.previousValue;
-    } else if (org_apache_flex_utils_Language.is(o, mx_states_SetEventHandler)) {
+    } else if (org_apache_flex_utils_Language.is(o, org_apache_flex_states_SetEventHandler)) {
       target = o.document[o.target];
       target.removeEventListener(o.name, o.handlerFunction);
     }
@@ -159,7 +159,7 @@ org_apache_flex_core_SimpleStatesImpl.prototype.revert_ = function(s) {
 
 /**
  * @private
  * @param {mx_states_State} s The State to apply.
  */
 org_apache_flex_core_SimpleStatesImpl.prototype.apply_ = function(s) {
   var arr, child, index, item, o, p, q, target;
@@ -170,7 +170,7 @@ org_apache_flex_core_SimpleStatesImpl.prototype.apply_ = function(s) {
   arr = s.overrides;
   for (p in arr) {
     o = arr[p];
-    if (org_apache_flex_utils_Language.is(o, mx_states_AddItems)) {
+    if (org_apache_flex_utils_Language.is(o, org_apache_flex_states_AddItems)) {
       if (!o.items) {
         o.items = o.itemsDescriptor.items;
         if (o.items == null) {
@@ -206,12 +206,12 @@ org_apache_flex_core_SimpleStatesImpl.prototype.apply_ = function(s) {
             new org_apache_flex_events_Event('childrenAdded'));
       }
     }
-    else if (org_apache_flex_utils_Language.is(o, mx_states_SetProperty))
+    else if (org_apache_flex_utils_Language.is(o, org_apache_flex_states_SetProperty))
     {
       target = o.document[o.target];
       o.previousValue = target[o.name];
       target[o.name] = o.value;
-    } else if (org_apache_flex_utils_Language.is(o, mx_states_SetEventHandler)) {
+    } else if (org_apache_flex_utils_Language.is(o, org_apache_flex_states_SetEventHandler)) {
       target = o.document[o.target];
       target.addEventListener(o.name, o.handlerFunction);
     }

http://git-wip-us.apache.org/repos/asf/flex-asjs/blob/d54a5937/frameworks/projects/Core/js/src/org/apache/flex/states/AddItems.js
----------------------------------------------------------------------
@@ -122,7 +122,7 @@ org_apache_flex_core_SimpleStatesImpl.prototype.stateChangeHandler_ =
 /**
  * @private
- * @param {mx_states_State} s The State to revert.
+ * @param {org_apache_flex_states_State} s The State to revert.
  */
 org_apache_flex_core_SimpleStatesImpl.prototype.revert_ = function(s) {
@@ -159,7 +159,7 @@ org_apache_flex_core_SimpleStatesImpl.prototype.revert_ = function(s) {
 /**
  * @private
- * @param {mx_states_State} s The State to apply.
+ * @param {org_apache_flex_states_State} s The State to apply.
  */
 org_apache_flex_core_SimpleStatesImpl.prototype.apply_ = function(s) {